@@ -304,7 +304,9 @@ def execute(args, parser):
     info_dict = get_info_dict(args.system)
 
     if (args.all or all(not getattr(args, opt) for opt in options)) and not context.json:
-        print(get_main_info_str(info_dict))
+        stdout_logger = getLogger("conda.stdoutlog")
+        stdout_logger.info(get_main_info_str(info_dict))
+        stdout_logger.info("\n")
 
     if args.envs:
         from ..core.envs_manager import list_all_known_prefixes
