@@ -11,7 +11,7 @@ import textwrap
 from conda._vendor.auxlib.path import expand
 from conda.cli import install as cli_install
 from conda.cli.conda_argparse import add_parser_json, add_parser_prefix
-from conda.gateways.disk.delete import delete_trash, rm_rf
+from conda.gateways.disk.delete import rm_rf
 from conda.misc import touch_nonadmin
 from .common import get_prefix
 from .. import exceptions, specs
@@ -117,6 +117,5 @@ def execute(args, parser):
             return -1
 
     touch_nonadmin(prefix)
-    delete_trash()
     if not args.json:
         cli_install.print_activate(args.name if args.name else prefix)
