@@ -7,8 +7,12 @@ import os
 import os.path as op
 import subprocess
 import tempfile
+from conda.base.context import context
+from conda.common.compat import on_win
+from conda.utils import wrap_subprocess_call
 from conda_env.pip_util import pip_args
 from conda.exceptions import CondaValueError
+from conda.gateways.disk.delete import rm_rf
 
 
 def _pip_install_via_requirements(prefix, specs, args, *_, **kwargs):
@@ -43,9 +47,14 @@ def _pip_install_via_requirements(prefix, specs, args, *_, **kwargs):
         args, pip_version = pip_args(prefix)
         if args is None:
             return
+        script_caller = None
         pip_cmd = args + ['install', '-r', requirements.name]
+        cmd = " ".join(pip_cmd)
+        script_caller, command_args = wrap_subprocess_call(
+            on_win, context.root_prefix, prefix, cmd
+        )
         # ...run it
-        process = subprocess.Popen(pip_cmd,
+        process = subprocess.Popen(command_args,
                                    cwd=pip_workdir,
                                    universal_newlines=True)
         process.communicate()
@@ -56,6 +65,8 @@ def _pip_install_via_requirements(prefix, specs, args, *_, **kwargs):
         # So we delete the temporary file in a finally block.
         if requirements is not None and op.isfile(requirements.name):
             os.remove(requirements.name)
+        if script_caller is not None:
+            rm_rf(script_caller)
 
 
 # Conform to Installers API
